import os
import inspect
import tarfile

import pytest

import tarsafe
from tarsafe import TarSafe, TarSafeException


def test_bad_files():
    files = os.listdir("./test/data/bad")
    for file_ in files:
        with pytest.raises(TarSafeException) as ex:
            with TarSafe.open(f"./test/data/bad/{file_}", "r") as tar:
                tar.extractall()


def test_good_files():
    files = os.listdir("./test/data/good")
    for file_ in files:
        with TarSafe.open(f"./test/data/good/{file_}", "r") as tar:
            tar.extractall()
        assert os.path.exists("./evil.sh")
        os.remove("./evil.sh")


def test_good_file():
    files = os.listdir("./test/data/good")
    for file_ in files:
        with TarSafe.open(f"./test/data/good/{file_}", "r") as tar:
            tar.extract("evil.sh")
        assert os.path.exists("./evil.sh")
        os.remove("./evil.sh")


def test_tarsafe_is_dropin_for_tarfile():
    assert _get_exposed_members(tarfile) <= _get_exposed_members(tarsafe)


def _get_exposed_members(module):
    return set(module.__all__)




from setuptools import setup, find_packages
from os import path

here = path.abspath(path.dirname(__file__))

from tarsafe import __version__

with open(path.join(here, 'README.md')) as file:
    long_description = file.read()

setup(
    name='tarsafe',
    version=__version__,
    description='A safe subclass of the TarFile class for interacting with tar files. Can be used as a direct drop-in replacement for safe usage of extractall()',
    long_description=long_description,
    long_description_content_type='text/plain',
    author='Andrew Scott',
    url='https://github.com/beatsbears/tarsafe',
    packages=find_packages(exclude=['tests*']),
    license='MIT License',
    install_requires=[],
    python_requires='>=3.6'
)